export declare class HttpClient {
    private readonly host;
    private readonly apiKey;
    /**
     * Blockcc Api Client
     * @param apiKey
     * @param host
     */
    constructor(apiKey: string, host?: string);
    /**
     * Gets the ticker information for params
     * @param market
     * @param slug
     * @param symbol
     * @param currency
     * @param market_pair
     * @param page
     * @param size
     */
    getTickers(market?: string, slug?: string, symbol?: string, currency?: string, market_pair?: string, page?: number, size?: number): Promise<any>;
    /**
     * Gets the price information for a given slug
     * @param slug
     * @param page
     * @param size
     */
    getPrices(slug?: string, page?: number, size?: number): Promise<any>;
    /**
     * Gets the OrderBook information for a given desc
     * @param desc
     * @param limit
     */
    getOrderBook(desc: string, limit?: number): Promise<any>;
    /**
     * Gets the Market information for a given slug
     * @param slug
     * @param page
     * @param size
     */
    getMarkets(slug?: string, page?: number, size?: number): Promise<any>;
    /**
     * Gets the Symbols information for a given slug
     * @param slug
     * @param details
     * @param page
     * @param size
     */
    getSymbols(slug?: string, details?: boolean, page?: number, size?: number): Promise<any>;
    /**
     * Gets the HistoryPrices information for given params
     * @param slug
     * @param start
     * @param end
     * @param interval
     */
    getHistoryPrices(slug: string, start?: number, end?: number, interval?: Interval): Promise<any>;
    /**
     * Gets Trade information for a given desc
     * @param desc
     * @param limit
     */
    getTrades(desc: string, limit?: number): Promise<any>;
    /**
     * Gets kline information for a given desc
     * @param desc
     * @param interval
     * @param end
     * @param start
     */
    getKline(desc: string, interval?: Interval, end?: number, start?: number): Promise<any>;
    /**
     * Get the latest exchangeRate
     */
    getExchangeRate(): Promise<any>;
    /**
     * Get the latest briefs information
     * @param locale
     * @param page
     * @param size
     */
    getBriefs(locale: Locale, page?: number, size?: number): Promise<any>;
    /**
     * Get the latest Announcements for markets
     * @param locale
     * @param market
     * @param page
     * @param size
     */
    getAnnouncements(locale: Locale, market?: string, page?: number, size?: number): Promise<any>;
    /**
     * Get articles information
     * @param locale
     * @param page
     * @param size
     */
    getArticles(locale: Locale, page?: number, size?: number): Promise<any>;
    /**
     * Get article for a given id
     * @param id
     */
    getArticle(id: string): Promise<any>;
    /**
     * Get social media for a given source
     * @param source
     * @param page
     * @param size
     */
    getSocialMedia(source?: Source, page?: number, size?: number): Promise<any>;
}
export declare class WebSocketClient {
    private readonly host;
    private readonly apiKey;
    constructor(apiKey: string, host?: string);
    /**
     * subscribe topic
     * @param cb callback
     * @param params
     */
    subscribe: (cb: any, ...params: any[]) => void;
}
export declare class Interval {
    static readonly ONE_MIN = "1m";
    static readonly FIVE_MIN = "5m";
    static readonly FIFTEEN_MIN = "15m";
    static readonly THIRTY_MIN = "30m";
    static readonly ONE_HOUR = "1h";
    static readonly TWO_HOUR = "2h";
    static readonly SIX_HOUR = "6h";
    static readonly TWELVE_HOUR = "12h";
    static readonly ONE_DAY = "1d";
    static readonly TWO_DAY = "2d";
}
export declare class Locale {
    static readonly zh_CN = "zh_CN";
    static readonly en_US = "en_US";
    static readonly ko_KR = "ko_KR";
}
export declare class Source {
    static readonly WEIBO = "WEIBO";
    static readonly TWITTER = "TWITTER";
}
export declare function price(coinId: string): string;
export declare function ticker(desc: string): string;
export declare function orderbook(desc: string): string;
